<?php
/**
 * @file
 * Helper class building graphic data to draw the EPC svg diagram.
 */

/**
 * Class EpcgegEpc.
 */
class EpcgegEpc extends EpcgegGraph {

  /**
   * Epcgeg_epc constructor.
   *
   * @param int $score
   *   The field value.
   * @param int $width
   *   The diagram width.
   * @param int $height
   *   The diagram height.
   * @param int $pad
   *   The space between bars.
   */
  public function __construct($score, $width, $height, $pad) {
    parent::__construct($score, $width, $height, $pad);
    $this->data = array(
      array(
        'letter' => 'A',
        'bounds' => array(NULL, variable_get('epcgeg_epc_A', 50)),
      ),
      array(
        'letter' => 'B',
        'bounds' => array(
          variable_get('epcgeg_epc_A', 50) + 1,
          variable_get('epcgeg_epc_B', 90),
        ),
      ),
      array(
        'letter' => 'C',
        'bounds' => array(
          variable_get('epcgeg_epc_B', 90) + 1,
          variable_get('epcgeg_epc_C', 150),
        ),
      ),
      array(
        'letter' => 'D',
        'bounds' => array(
          variable_get('epcgeg_epc_C', 150) + 1,
          variable_get('epcgeg_epc_D', 230),
        ),
      ),
      array(
        'letter' => 'E',
        'bounds' => array(
          variable_get('epcgeg_epc_D', 230) + 1,
          variable_get('epcgeg_epc_E', 330),
        ),
      ),
      array(
        'letter' => 'F',
        'bounds' => array(
          variable_get('epcgeg_epc_E', 330) + 1,
          variable_get('epcgeg_epc_F', 450),
        ),
      ),
      array(
        'letter' => 'G',
        'bounds' => array(variable_get('epcgeg_epc_F', 450), NULL),
      ),
    );
    $this->bar_height = ($this->height + $this->pad) / 7 - $this->pad;
    $this->bar_width = $this->width - 3 * $this->bar_height;
  }

  /**
   * Overriding the bar polygon definition.
   *
   * @param int $x
   *   Bar left horizontal position.
   * @param int $y
   *   Bar top vertical position.
   * @param int $x1
   *   Bar right horizontal position.
   * @param int $y1
   *   Bar bottom horizontal position.
   *
   * @return string
   *   Svg polygon points attribute.
   */
  protected function getPolygon($x, $y, $x1, $y1) {
    return implode(' ', array(
      $x . ',' . $y,
      $x1 . ',' . $y,
      ($x1 + $this->bar_height / 2) . ',' . (($y + $y1) / 2),
      $x1 . ',' . $y1,
      $x . ',' . $y1,
      $x . ',' . $y,
    ));
  }

}
