<?php
/**
 * @file
 * Helper class building graphic data to draw the GEG svg diagram.
 */

/**
 * Class EpcgegGeg.
 */
class EpcgegGeg extends EpcgegGraph {

  /**
   * Epcgeg_geg constructor.
   *
   * @param int $score
   *   The field value.
   * @param int $width
   *   The diagram width.
   * @param int $height
   *   The diagram height.
   * @param int $pad
   *   The space between bars.
   */
  public function __construct($score, $width, $height, $pad) {
    parent::__construct($score, $width, $height, $pad);
    $this->data = array(
      array(
        'letter' => 'A',
        'bounds' => array(NULL, variable_get('epcgeg_geg_A', 5)),
      ),
      array(
        'letter' => 'B',
        'bounds' => array(
          variable_get('epcgeg_geg_A', 5) + 1,
          variable_get('epcgeg_geg_B', 10),
        ),
      ),
      array(
        'letter' => 'C',
        'bounds' => array(
          variable_get('epcgeg_geg_B', 10) + 1,
          variable_get('epcgeg_geg_C', 20),
        ),
      ),
      array(
        'letter' => 'D',
        'bounds' => array(
          variable_get('epcgeg_geg_C', 20) + 1,
          variable_get('epcgeg_geg_D', 35),
        ),
      ),
      array(
        'letter' => 'E',
        'bounds' => array(
          variable_get('epcgeg_geg_D', 35) + 1,
          variable_get('epcgeg_geg_E', 55),
        ),
      ),
      array(
        'letter' => 'F',
        'bounds' => array(
          variable_get('epcgeg_geg_E', 55) + 1,
          variable_get('epcgeg_geg_F', 80),
        ),
      ),
      array(
        'letter' => 'G',
        'bounds' => array(variable_get('epcgeg_geg_F', 80), NULL),
      ),
    );
    $this->bar_height = ($this->height + $this->pad) / 7 - $this->pad;
    $this->bar_width = $this->width - 2.5 * $this->bar_height;

  }

  /**
   * Overriding the bar polygon definition.
   *
   * @param int $x
   *   Bar left horizontal position.
   * @param int $y
   *   Bar top vertical position.
   * @param int $x1
   *   Bar right horizontal position.
   * @param int $y1
   *   Bar bottom horizontal position.
   *
   * @return string
   *   Svg polygon points attribute.
   */
  protected function getPolygon($x, $y, $x1, $y1) {
    return implode(' ', array(
      $x . ',' . $y,
      $x1 . ',' . $y,
      $x1 . ',' . $y1,
      $x . ',' . $y1,
      $x . ',' . $y,
    ));
  }

}
